@@ -16,7 +16,8 @@ from .json_utils import (unified_json_loader,
                          get_any_value,
                          json_key_or_default,
                          format_json_key_values,
-                         get_all_keys)
+                         get_all_keys,
+                         update_dict_value)
 from .read_write_utils import (read_from_file,
                                write_to_file)
 from .path_utils import (get_file_create_time,
@@ -59,3 +60,4 @@ from .abstract_classes import *
 from .parse_utils import (num_tokens_from_string,
                           chunk_source_code,
                           chunk_any_to_tokens)
+from .log_utils import get_logFile
