@@ -26,13 +26,13 @@ import json
 import re
 import os
 import logging
-from .read_write_utils import check_read_write_params,read_from_file,write_to_file
+from .read_write_utils import check_read_write_params, read_from_file, write_to_file
 from .compare_utils import get_closest_match_from_list
 from .path_utils import makeAllDirs
-from .type_utils import make_list,convert_and_normalize_values
+from .type_utils import make_list, convert_and_normalize_values
 from typing import List, Union, Dict, Any
-logging.basicConfig(level=logging.INFO)
-logging.basicConfig(level=logging.DEBUG,format='%(asctime)s - %(levelname)s - %(message)s')
+
+logging.basicConfig(level=logging.DEBUG, format='%(asctime)s - %(levelname)s - %(message)s')
 logger = logging.getLogger(__name__)
 def json_key_or_default(json_data,key,default_value):
     json_data = safe_json_loads(json_data)
@@ -95,26 +95,28 @@ def safe_write_to_json(file_path:str=None, data:(dict or list or str)=None,*args
                 safe_dump_to_file(params[1], file, ensure_ascii=ensure_ascii, indent=indent)
         
             os.replace(temp_file_path, params[0])
-def safe_dump_to_file(file_path:str=None, data:(dict or list or str)=None, ensure_ascii=False, indent=4,*args, **kwargs):
-    params = check_read_write_params(file_path=file_path,contents=data, *args, **kwargs)
-    if params:
+def safe_dump_to_file(data, file_path=None, ensure_ascii=False, indent=4, *args, **kwargs):
+    file_path, data = check_read_write_params(file_path=file_path, contents=data, *args, **kwargs)
+    if file_path and data is not None:
         try:
-            if isinstance(params[1], (dict, list, tuple)):
-                with open(params[0], 'w', encoding='utf-8') as file:
-                    json.dump(params[1], file, ensure_ascii=ensure_ascii, indent=indent)
+            if isinstance(data, (dict, list, tuple)):
+                with open(file_path, 'w', encoding='utf-8') as file:
+                    json.dump(data, file, ensure_ascii=ensure_ascii, indent=indent)
             else:
-                with open(params[0], 'w', encoding='utf-8') as file:
-                    file.write(str(params[1]))
+                with open(file_path, 'w', encoding='utf-8') as file:
+                    file.write(str(data))
         except Exception as e:
-            logger.error(f"type: Error\nfunction: safe_dump_to_file \nscript: abstract_utilities.json_utils\nerror: {e}\n data: {file_path,data}")
-            
+            logger.error(f"Error in safe_dump_to_file: {e}\nData: {file_path}, {data}")
+    else:
+        logger.error("file_path and data must be provided to safe_dump_to_file")
+
 def safe_read_from_json(file_path):
     try:
         with open(file_path, 'r', encoding='utf-8') as file:
             return json.load(file)
     except Exception as e:
-        logger.error(f"type: Error\nfunction: safe_read_from_json \nscript: abstract_utilities.json_utils\nerror: {e}\n data: {file_path}")
-        return safe_json_loads(read_from_file(file_path))
+        logger.error(f"Error in safe_read_from_json: {e}\nFile path: {file_path}")
+        return None
 def find_keys(data, target_keys):
     def _find_keys_recursive(data, target_keys, values):
         if isinstance(data, dict):
@@ -440,3 +442,23 @@ def get_all_keys(dict_data,keys=[]):
       keys.append(key)
       keys = get_all_keys(value,keys=keys)
   return keys
+
+def update_dict_value(data, paths, new_value):
+    """
+    Traverses a dictionary to the specified key path and updates its value.
+    
+    Args:
+        data (dict): The dictionary to traverse.
+        paths (list): The list of keys leading to the target value.
+        new_value (any): The new value to assign to the specified key.
+
+    Returns:
+        dict: The updated dictionary.
+    """
+    d = data
+    for key in paths[:-1]:
+        # Traverse the dictionary up to the second-to-last key
+        d = d[key]
+    # Update the value at the final key
+    d[paths[-1]] = new_value
+    return data
